# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'AnalyticsSolutionPlan',
]

@pulumi.output_type
class AnalyticsSolutionPlan(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "promotionCode":
            suggest = "promotion_code"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AnalyticsSolutionPlan. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AnalyticsSolutionPlan.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AnalyticsSolutionPlan.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 product: str,
                 publisher: str,
                 name: Optional[str] = None,
                 promotion_code: Optional[str] = None):
        """
        :param str product: The product name of the solution. For example `OMSGallery/Containers`. Changing this forces a new resource to be created.
        :param str publisher: The publisher of the solution. For example `Microsoft`. Changing this forces a new resource to be created.
        :param str promotion_code: A promotion code to be used with the solution.
        """
        pulumi.set(__self__, "product", product)
        pulumi.set(__self__, "publisher", publisher)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if promotion_code is not None:
            pulumi.set(__self__, "promotion_code", promotion_code)

    @property
    @pulumi.getter
    def product(self) -> str:
        """
        The product name of the solution. For example `OMSGallery/Containers`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "product")

    @property
    @pulumi.getter
    def publisher(self) -> str:
        """
        The publisher of the solution. For example `Microsoft`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "publisher")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="promotionCode")
    def promotion_code(self) -> Optional[str]:
        """
        A promotion code to be used with the solution.
        """
        return pulumi.get(self, "promotion_code")


